#ifndef __TXT2GAL_H
# define __TXT2GAL_H
/*
*  txt2gcal.h:  Creates a verbatim Gcal resource file from a text file header file.
*
*
*  Copyright (c) 2000-2010 Free Software Foundation, Inc.
*  Copyright (c) 1996, 1997, 2000 Thomas Esken
*
*  This software doesn't claim completeness, correctness or usability.
*  On principle I will not be liable for ANY damages or losses (implicit
*  or explicit), which result from using or handling my software.
*  If you use this software, you agree without any exception to this
*  agreement, which binds you LEGALLY !!
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the `GNU General Public License' as published by
*  the `Free Software Foundation'; either version 3, or (at your option)
*  any later version.
*
*  You should have received a copy of the `GNU General Public License'
*  along with this program; if not, write to the:
*
*/



/*
*  $Id: txt2gcal.h 3.06 2000/06/14 03:00:06 tom Exp $
*/



/*
*  GLOBAL functions prototypes.
*/
__BEGIN_DECLARATIONS extern int main __P_ ((int argc, char *argv[]));
__END_DECLARATIONS
#endif /* __TXT2GCAL_H */
